# Example Package that simulates a set of bouncing balls in a closed room

Simulates a set of bouncing balls in a closed room. This package uses law of conservation of momentum and energy to simulate different levels of elastic collisions by setting the elastic coefficient (eCoefft).

The number of balls and ball color can also be set.

The library can also save and re-load states.